# Bionty

Managing biological entities.

## Requirements

Python 3.8+

## Installation

<div class="termy">

```console
$ pip install bionty
```

</div>

Install the development version:

<div class="termy">

```console
$ flit install -s --deps develop
```

</div>

## Quickstart

- https://lamin.ai/bionty/guides/quickstart
